@@ -44,7 +44,7 @@ copyright = '2013, Bob Ippolito'
 # The short X.Y version.
 version = '3.1'
 # The full version, including alpha/beta/rc tags.
-release = '3.1'
+release = '3.1.2'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
